@@ -1,7 +1,7 @@
-from .refgenie import main
+from .cli import main
 import sys
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     try:
         sys.exit(main())
     except KeyboardInterrupt:
