@@ -1,9 +1,11 @@
 """
-Constant variables for refgenie package.
-Ones that are integral to refgenconf and/or refgenieserver should be defined in refgenconf.const
+Constant variables for refgenie package. Ones that are integral to refgenconf
+and/or refgenieserver should be defined in refgenconf.const
 """
 from refgenconf.const import *
 
+PKG_NAME = "refgenie"
+
 BUILD_CMD = "build"
 INIT_CMD = "init"
 PULL_CMD = "pull"
@@ -17,6 +19,9 @@ TAG_CMD = "tag"
 ID_CMD = "id"
 SUBSCRIBE_CMD = "subscribe"
 UNSUBSCRIBE_CMD = "unsubscribe"
+ALIAS_CMD = "alias"
+COMPARE_CMD = "compare"
+UPGRADE_CMD = "upgrade"
 
 GENOME_ONLY_REQUIRED = [REMOVE_CMD, GETSEQ_CMD]
 
@@ -37,4 +42,17 @@ SUBPARSER_MESSAGES = {
     ID_CMD: "Return the asset digest.",
     SUBSCRIBE_CMD: "Add a refgenieserver URL to the config.",
     UNSUBSCRIBE_CMD: "Remove a refgenieserver URL from the config.",
+    ALIAS_CMD: "Interact with aliases.",
+    COMPARE_CMD: "Compare two genomes.",
+    UPGRADE_CMD: "Upgrade config. This will alter the files on disk.",
+}
+
+ALIAS_GET_CMD = "get"
+ALIAS_SET_CMD = "set"
+ALIAS_REMOVE_CMD = "remove"
+
+ALIAS_SUBPARSER_MESSAGES = {
+    ALIAS_REMOVE_CMD: "Remove aliases.",
+    ALIAS_SET_CMD: "Set aliases.",
+    ALIAS_GET_CMD: "Get aliases.",
 }
