@@ -1,10 +1,11 @@
 from refgenconf import CFG_ENV_VARS
 
-__all__ = ["RefgenieError", "MissingGenomeConfigError"]
+__all__ = ["RefgenieError", "MissingGenomeConfigError", "MissingFolderError"]
 
 
 class RefgenieError(Exception):
     """ Base refgenie exception type """
+
     pass
 
 
@@ -17,8 +18,9 @@ class MissingGenomeConfigError(RefgenieError):
 
         :param str conf_file: path attempted to be used as genome config file
         """
-        msg = "You must provide a config file either as an argument or via an environment variable: {}"\
-            .format(", ".join(CFG_ENV_VARS))
+        msg = "You must provide a config file either as an argument or via an environment variable: {}".format(
+            ", ".join(CFG_ENV_VARS)
+        )
         if conf_file:
             msg = "Not a file {} -- {}.".format(conf_file, msg)
         super(MissingGenomeConfigError, self).__init__(msg)
@@ -32,4 +34,3 @@ class MissingFolderError(RefgenieError):
         :param str folder: path attempted to be used as folder to save a file to
         """
         super(MissingFolderError, self).__init__(folder)
-
